@@ -8,8 +8,8 @@
 #' @examples
 #' r(print("yeay"))
 #' r(install.packages("plumber", repo = "http://cran.irsn.fr/"))
-
-r <- function(code){
-  code <- deparse(substitute(code))
+r <- function(code) {
+  code <- paste(deparse(substitute(code)), collapse = " ")
+  code <- gsub(" [2,]", " ", code)
   glue("R -e '{code}'")
 }
